Module value

Module value 

Bound value model for v2.

Value is the dialect-agnostic representation of a bound parameter. The IntoBind trait converts common Rust types into a Value so they can be used ergonomically as query bindings.

Enums

Value
A dialect-agnostic bound parameter value.

Traits

IntoBind
Conversion of a Rust value into a bound Value.