Bound value model for v2.
Value is the dialect-agnostic representation of a bound parameter. The IntoBind trait converts common Rust types into a Value so they can be used ergonomically as query bindings.
Value
IntoBind